@@ -1,8 +1,9 @@
-from django.conf import settings
 from django.core.exceptions import MultipleObjectsReturned
 
+from social_auth.utils import setting
 from social_auth.models import User
 from social_auth.backends.pipeline import warn_setting
+from social_auth.backends.exceptions import AuthException
 
 
 def associate_by_email(details, *args, **kwargs):
@@ -11,13 +12,13 @@ def associate_by_email(details, *args, **kwargs):
 
     warn_setting('SOCIAL_AUTH_ASSOCIATE_BY_MAIL', 'associate_by_email')
 
-    if email and getattr(settings, 'SOCIAL_AUTH_ASSOCIATE_BY_MAIL', False):
+    if email and setting('SOCIAL_AUTH_ASSOCIATE_BY_MAIL'):
         # try to associate accounts registered with the same email address,
-        # only if it's a single object. ValueError is raised if multiple
+        # only if it's a single object. AuthException is raised if multiple
         # objects are returned
         try:
             return {'user': User.objects.get(email=email)}
         except MultipleObjectsReturned:
-            raise ValueError('Not unique email address.')
+            raise AuthException(kwargs['backend'], 'Not unique email address.')
         except User.DoesNotExist:
             pass
